[geos-commits] r2961 - in trunk/include/geos: algorithm geom geom/prep geomgraph index/chain index/strtree noding noding/snapround operation/predicate planargraph simplify

svn_geos at osgeo.org svn_geos at osgeo.org
Mon Mar 29 08:17:38 EDT 2010


Author: mloskot
Date: 2010-03-29 08:17:37 -0400 (Mon, 29 Mar 2010)
New Revision: 2961

Modified:
   trunk/include/geos/algorithm/CentralEndpointIntersector.h
   trunk/include/geos/geom/CoordinateArraySequence.h
   trunk/include/geos/geom/CoordinateArraySequenceFactory.h
   trunk/include/geos/geom/CoordinateArraySequenceFactory.inl
   trunk/include/geos/geom/CoordinateSequence.h
   trunk/include/geos/geom/CoordinateSequenceFactory.h
   trunk/include/geos/geom/CoordinateSequenceFilter.h
   trunk/include/geos/geom/Geometry.h
   trunk/include/geos/geom/GeometryCollection.h
   trunk/include/geos/geom/LineSegment.h
   trunk/include/geos/geom/LineSegment.inl
   trunk/include/geos/geom/LineString.h
   trunk/include/geos/geom/Polygon.h
   trunk/include/geos/geom/prep/PreparedLineStringIntersects.h
   trunk/include/geos/geomgraph/EdgeEndStar.h
   trunk/include/geos/geomgraph/TopologyLocation.h
   trunk/include/geos/index/chain/MonotoneChain.h
   trunk/include/geos/index/chain/MonotoneChainBuilder.h
   trunk/include/geos/index/chain/MonotoneChainOverlapAction.h
   trunk/include/geos/index/strtree/AbstractSTRtree.h
   trunk/include/geos/index/strtree/SIRtree.h
   trunk/include/geos/index/strtree/STRtree.h
   trunk/include/geos/noding/MCIndexNoder.h
   trunk/include/geos/noding/MCIndexSegmentSetMutualIntersector.h
   trunk/include/geos/noding/SegmentNodeList.h
   trunk/include/geos/noding/SegmentStringUtil.h
   trunk/include/geos/noding/snapround/HotPixel.h
   trunk/include/geos/operation/predicate/RectangleIntersects.h
   trunk/include/geos/planargraph/DirectedEdgeStar.h
   trunk/include/geos/planargraph/PlanarGraph.h
   trunk/include/geos/simplify/DouglasPeuckerLineSimplifier.h
   trunk/include/geos/simplify/TaggedLineString.h
Log:
Qualify size_t with std namespace in headers.

Modified: trunk/include/geos/algorithm/CentralEndpointIntersector.h
===================================================================
--- trunk/include/geos/algorithm/CentralEndpointIntersector.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/algorithm/CentralEndpointIntersector.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -106,7 +106,7 @@
 		geom::Coordinate avg(0, 0);
 		size_t n = pts.size();
 		if ( ! n ) return avg;
-		for (size_t i=0; i<n; ++i)
+		for (std::size_t i=0; i<n; ++i)
 		{
 			avg.x += pts[i].x;
 			avg.y += pts[i].y;
@@ -131,7 +131,7 @@
 	{
 		double minDist = std::numeric_limits<double>::max();
 		geom::Coordinate result = geom::Coordinate::getNull();
-		for (size_t i = 0, n=pts.size(); i < n; ++i) {
+		for (std::size_t i = 0, n=pts.size(); i < n; ++i) {
 			double dist = p.distance(pts[i]);
 			if (dist < minDist) {
 				minDist = dist;

Modified: trunk/include/geos/geom/CoordinateArraySequence.h
===================================================================
--- trunk/include/geos/geom/CoordinateArraySequence.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/CoordinateArraySequence.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -44,10 +44,10 @@
 	CoordinateSequence *clone() const;
 
 	//const Coordinate& getCoordinate(int pos) const;
-	const Coordinate& getAt(size_t pos) const;
+	const Coordinate& getAt(std::size_t pos) const;
 
 	/// Copy Coordinate at position i to Coordinate c
-	virtual void getAt(size_t i, Coordinate& c) const;
+	virtual void getAt(std::size_t i, Coordinate& c) const;
 
 	//int size() const;
 	size_t getSize() const;
@@ -65,7 +65,7 @@
 	CoordinateArraySequence(std::vector<Coordinate> *coords);
 
 	/// Construct sequence allocating space for n coordinates
-	CoordinateArraySequence(size_t n);
+	CoordinateArraySequence(std::size_t n);
 
 	~CoordinateArraySequence();
 
@@ -86,20 +86,20 @@
 	 *
 	 * NOTE: this is a CoordinateList interface in JTS
 	 */
-	virtual void add(size_t i, const Coordinate& coord, bool allowRepeated);
+	virtual void add(std::size_t i, const Coordinate& coord, bool allowRepeated);
 
-	void setAt(const Coordinate& c, size_t pos);
+	void setAt(const Coordinate& c, std::size_t pos);
 
-	void deleteAt(size_t pos);
+	void deleteAt(std::size_t pos);
 
 	std::string toString() const;
 
 	void setPoints(const std::vector<Coordinate> &v);
 
-	double getOrdinate(size_t index,
+	double getOrdinate(std::size_t index,
 			size_t ordinateIndex) const;
 
-	void setOrdinate(size_t index, size_t ordinateIndex,
+	void setOrdinate(std::size_t index, std::size_t ordinateIndex,
 			double value);
 
 	void expandEnvelope(Envelope &env) const;

Modified: trunk/include/geos/geom/CoordinateArraySequenceFactory.h
===================================================================
--- trunk/include/geos/geom/CoordinateArraySequenceFactory.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/CoordinateArraySequenceFactory.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -51,10 +51,10 @@
 	 */
 	CoordinateSequence *create(std::vector<Coordinate> *coords) const;
 
-	CoordinateSequence *create(std::vector<Coordinate> *coords, size_t dims) const;
+	CoordinateSequence *create(std::vector<Coordinate> *coords, std::size_t dims) const;
 
-   	/** @see CoordinateSequenceFactory::create(size_t, int) */
-	CoordinateSequence *create(size_t size, size_t dimension=3) const;
+   	/** @see CoordinateSequenceFactory::create(std::size_t, int) */
+	CoordinateSequence *create(std::size_t size, std::size_t dimension=3) const;
 
 	/** \brief
 	 * Returns the singleton instance of CoordinateArraySequenceFactory

Modified: trunk/include/geos/geom/CoordinateArraySequenceFactory.inl
===================================================================
--- trunk/include/geos/geom/CoordinateArraySequenceFactory.inl	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/CoordinateArraySequenceFactory.inl	2010-03-29 12:17:37 UTC (rev 2961)
@@ -37,7 +37,7 @@
 }
 
 INLINE CoordinateSequence *
-CoordinateArraySequenceFactory::create(size_t size, size_t /* dimension */)
+CoordinateArraySequenceFactory::create(std::size_t size, std::size_t /* dimension */)
 		const
 {
 	/* CoordinateArraySequence only accepts 3d Coordinates */

Modified: trunk/include/geos/geom/CoordinateSequence.h
===================================================================
--- trunk/include/geos/geom/CoordinateSequenceFactory.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/CoordinateSequenceFactory.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -75,7 +75,7 @@
 	 * @param dimension the dimension of the coordinates in the sequence
 	 * 	(if user-specifiable, otherwise ignored)
 	 */
-	virtual CoordinateSequence *create(size_t size,
+	virtual CoordinateSequence *create(std::size_t size,
 			size_t dimension) const=0;
 
 	virtual ~CoordinateSequenceFactory();

Modified: trunk/include/geos/geom/CoordinateSequenceFilter.h
===================================================================
--- trunk/include/geos/geom/CoordinateSequenceFilter.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/CoordinateSequenceFilter.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -68,7 +68,7 @@
    *             is applied
    * @param i the index of the coordinate to apply the filter to
    */
-  virtual void filter_rw(CoordinateSequence& /*seq*/, size_t /*i*/)
+  virtual void filter_rw(CoordinateSequence& /*seq*/, std::size_t /*i*/)
   { assert(0); }
 
   /**
@@ -78,7 +78,7 @@
    *             is applied
    * @param i the index of the coordinate to apply the filter to
    */
-  virtual void filter_ro(const CoordinateSequence& /*seq*/, size_t /*i*/)
+  virtual void filter_ro(const CoordinateSequence& /*seq*/, std::size_t /*i*/)
   { assert(0); }
 
   /**

Modified: trunk/include/geos/geom/Geometry.h
===================================================================
--- trunk/include/geos/geom/Geometry.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/Geometry.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -264,7 +264,7 @@
 	virtual CoordinateSequence* getCoordinates() const=0; //Abstract
 
 	/// Returns the count of this Geometrys vertices.
-	virtual size_t getNumPoints() const=0; //Abstract
+	virtual std::size_t getNumPoints() const=0; //Abstract
 
 	/// Returns false if the Geometry not simple.
 	virtual bool isSimple() const; 
@@ -277,11 +277,11 @@
 
 	/// Returns the number of geometries in this collection
 	/// (or 1 if this is not a collection)
-	virtual size_t getNumGeometries() const { return 1; }
+	virtual std::size_t getNumGeometries() const { return 1; }
 
 	/// Returns a pointer to the nth Geometry int this collection
 	/// (or self if this is not a collection)
-	virtual const Geometry* getGeometryN(size_t /*n*/) const { return this; }
+	virtual const Geometry* getGeometryN(std::size_t /*n*/) const { return this; }
 
 	/**
 	 * \brief Tests the validity of this <code>Geometry</code>.
@@ -664,7 +664,7 @@
 	template <class T>
 	void applyComponentFilter(T& f) const
 	{
-		for(size_t i=0, n=getNumGeometries(); i<n; ++i)
+		for(std::size_t i=0, n=getNumGeometries(); i<n; ++i)
 			f.filter(getGeometryN(i));
 	}
 

Modified: trunk/include/geos/geom/GeometryCollection.h
===================================================================
--- trunk/include/geos/geom/GeometryCollection.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/GeometryCollection.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -114,7 +114,7 @@
 	 */
 	virtual int getBoundaryDimension() const;
 
-	virtual size_t getNumPoints() const;
+	virtual std::size_t getNumPoints() const;
 
 	virtual std::string getGeometryType() const;
 
@@ -150,10 +150,10 @@
 	virtual double getLength() const;
 
 	/// Returns the number of geometries in this collection
-	virtual size_t getNumGeometries() const;
+	virtual std::size_t getNumGeometries() const;
 
 	/// Returns a pointer to the nth Geometry int this collection
-	virtual const Geometry* getGeometryN(size_t n) const;
+	virtual const Geometry* getGeometryN(std::size_t n) const;
 
 protected:
 

Modified: trunk/include/geos/geom/LineSegment.h
===================================================================
--- trunk/include/geos/geom/LineSegment.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/LineSegment.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -77,10 +77,10 @@
 	void setCoordinates(const Coordinate& c0, const Coordinate& c1);
 
 	// obsoleted, use operator[] instead
-	//const Coordinate& getCoordinate(size_t i) const;
+	//const Coordinate& getCoordinate(std::size_t i) const;
 
-	const Coordinate& operator[](size_t i) const;
-	Coordinate& operator[](size_t i);
+	const Coordinate& operator[](std::size_t i) const;
+	Coordinate& operator[](std::size_t i);
 
 	void setCoordinates(const LineSegment& ls);
 

Modified: trunk/include/geos/geom/LineSegment.inl
===================================================================
--- trunk/include/geos/geom/LineSegment.inl	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/LineSegment.inl	2010-03-29 12:17:37 UTC (rev 2961)
@@ -105,7 +105,7 @@
 }
 
 INLINE const Coordinate&
-LineSegment::operator[](size_t i) const
+LineSegment::operator[](std::size_t i) const
 {
 	if (i==0) return p0;
 	assert(i==1);
@@ -113,7 +113,7 @@
 }
 
 INLINE Coordinate&
-LineSegment::operator[](size_t i) 
+LineSegment::operator[](std::size_t i) 
 {
 	if (i==0) return p0;
 	assert(i==1);

Modified: trunk/include/geos/geom/LineString.h
===================================================================
--- trunk/include/geos/geom/LineString.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/LineString.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -99,9 +99,9 @@
 
 	virtual bool isEmpty() const;
 
-	virtual size_t getNumPoints() const;
+	virtual std::size_t getNumPoints() const;
 
-	virtual Point* getPointN(size_t n) const;
+	virtual Point* getPointN(std::size_t n) const;
 
 	/// \brief
 	/// Return the start point of the LineString

Modified: trunk/include/geos/geom/Polygon.h
===================================================================
--- trunk/include/geos/geom/Polygon.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/Polygon.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -116,7 +116,7 @@
 	size_t getNumInteriorRing() const;
 
 	/// Get nth interior ring (hole)
-	const LineString* getInteriorRingN(size_t n) const;
+	const LineString* getInteriorRingN(std::size_t n) const;
 
 	std::string getGeometryType() const;
 	virtual GeometryTypeId getGeometryTypeId() const;

Modified: trunk/include/geos/geom/prep/PreparedLineStringIntersects.h
===================================================================
--- trunk/include/geos/geom/prep/PreparedLineStringIntersects.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/prep/PreparedLineStringIntersects.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -101,7 +101,7 @@
 	//	geom::Coordinate::ConstVect coords;
 	//	ComponentCoordinateExtracter::getCoordinates( *testGeom, coords);
 
-	//	for (size_t i=0, n=coords.size(); i<n; i++)
+	//	for (std::size_t i=0, n=coords.size(); i<n; i++)
 	//	{
 	//		geom::Coordinate c = *(coords[i]);
 	//		if ( locator->intersects( c, &(prepLine->getGeometry()) ))

Modified: trunk/include/geos/geomgraph/EdgeEndStar.h
===================================================================
--- trunk/include/geos/geomgraph/EdgeEndStar.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geomgraph/EdgeEndStar.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -86,7 +86,7 @@
 	 */
 	virtual geom::Coordinate& getCoordinate();
 
-	virtual size_t getDegree();
+	virtual std::size_t getDegree();
 
 	virtual iterator begin();
 
@@ -145,7 +145,7 @@
 
 };
 
-inline size_t
+inline std::size_t
 EdgeEndStar::getDegree()
 {
 	return edgeMap.size();

Modified: trunk/include/geos/geomgraph/TopologyLocation.h
===================================================================
--- trunk/include/geos/geomgraph/TopologyLocation.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geomgraph/TopologyLocation.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -80,7 +80,7 @@
 
 	TopologyLocation(const TopologyLocation &gl);
 
-	int get(size_t posIndex) const;
+	int get(std::size_t posIndex) const;
 
 	/**
 	 * @return true if all locations are Location::UNDEF
@@ -104,7 +104,7 @@
 
 	void setAllLocationsIfNull(int locValue);
 
-	void setLocation(size_t locIndex, int locValue);
+	void setLocation(std::size_t locIndex, int locValue);
 
 	void setLocation(int locValue);
 

Modified: trunk/include/geos/index/chain/MonotoneChain.h
===================================================================
--- trunk/include/geos/index/chain/MonotoneChain.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/index/chain/MonotoneChain.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -98,7 +98,7 @@
 	///   Ownership left to caller, this class holds a reference.
 	///
 	MonotoneChain(const geom::CoordinateSequence& pts,
-                  size_t start, size_t end, void* context);
+                  std::size_t start, std::size_t end, void* context);
 
 	~MonotoneChain();
 
@@ -113,7 +113,7 @@
 	 *  Set given LineSegment with points of the segment starting
 	 *  at the given index.
 	 */
-	void getLineSegment(size_t index, geom::LineSegment& ls) const;
+	void getLineSegment(std::size_t index, geom::LineSegment& ls) const;
 
 	/**
 	 * Return the subsequence of coordinates forming this chain.
@@ -145,8 +145,8 @@
 			size_t end0,
 			MonotoneChainSelectAction& mcs);
 
-	void computeOverlaps(size_t start0, size_t end0, MonotoneChain& mc,
-			     size_t start1, size_t end1,
+	void computeOverlaps(std::size_t start0, std::size_t end0, MonotoneChain& mc,
+			     std::size_t start1, std::size_t end1,
 	                     MonotoneChainOverlapAction& mco);
 
 	/// Externally owned 

Modified: trunk/include/geos/index/chain/MonotoneChainBuilder.h
===================================================================
--- trunk/include/geos/index/chain/MonotoneChainBuilder.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/index/chain/MonotoneChainBuilder.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -97,8 +97,8 @@
 	 *
 	 * NOTE: aborts if 'start' is >= pts.getSize()
 	 */
-	static size_t findChainEnd(const geom::CoordinateSequence& pts,
-	                                                   size_t start);
+	static std::size_t findChainEnd(const geom::CoordinateSequence& pts,
+	                                                   std::size_t start);
 };
 
 } // namespace geos::index::chain

Modified: trunk/include/geos/index/chain/MonotoneChainOverlapAction.h
===================================================================
--- trunk/include/geos/index/chain/MonotoneChainOverlapAction.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/index/chain/MonotoneChainOverlapAction.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -64,8 +64,8 @@
 	 * @param start2 the index of the start of the overlapping segment
 	 *               from mc2
 	 */
-	virtual void overlap(MonotoneChain& mc1, size_t start1,
-	                     MonotoneChain& mc2, size_t start2);
+	virtual void overlap(MonotoneChain& mc1, std::size_t start1,
+	                     MonotoneChain& mc2, std::size_t start2);
 
 	/**
 	 * This is a convenience function which can be overridden to

Modified: trunk/include/geos/index/strtree/AbstractSTRtree.h
===================================================================
--- trunk/include/geos/index/strtree/AbstractSTRtree.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/index/strtree/AbstractSTRtree.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -231,7 +231,7 @@
 	std::auto_ptr<BoundableList> boundablesAtLevel(int level);
 
 	// @@ should be size_t, probably
-	size_t nodeCapacity;
+	std::size_t nodeCapacity;
 
 	/**
 	 * @return a test for intersection between two bounds,
@@ -248,7 +248,7 @@
 	 * Constructs an AbstractSTRtree with the specified maximum number of child
 	 * nodes that a node may have
 	 */
-	AbstractSTRtree(size_t newNodeCapacity)
+	AbstractSTRtree(std::size_t newNodeCapacity)
 		:
 		built(false),
 		itemBoundables(new BoundableList()),
@@ -279,7 +279,7 @@
 	/**
 	 * Returns the maximum number of child nodes that a node may have
 	 */
-	virtual size_t getNodeCapacity() { return nodeCapacity; }
+	virtual std::size_t getNodeCapacity() { return nodeCapacity; }
 
 	virtual void query(const void* searchBounds, const AbstractNode* node, std::vector<void*>* matches);
 

Modified: trunk/include/geos/index/strtree/SIRtree.h
===================================================================
--- trunk/include/geos/index/strtree/SIRtree.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/index/strtree/SIRtree.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -54,7 +54,7 @@
 	 * Constructs an SIRtree with the given maximum number of child nodes
 	 * that a node may have
 	 */
-	SIRtree(size_t nodeCapacity);
+	SIRtree(std::size_t nodeCapacity);
 
 	virtual ~SIRtree();
 

Modified: trunk/include/geos/index/strtree/STRtree.h
===================================================================
--- trunk/include/geos/index/strtree/STRtree.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/index/strtree/STRtree.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -118,7 +118,7 @@
 	 * Constructs an STRtree with the given maximum number of child nodes that
 	 * a node may have
 	 */
-	STRtree(size_t nodeCapacity=10);
+	STRtree(std::size_t nodeCapacity=10);
 
 	void insert(const geom::Envelope *itemEnv,void* item);
 

Modified: trunk/include/geos/noding/MCIndexNoder.h
===================================================================
--- trunk/include/geos/noding/MCIndexNoder.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/noding/MCIndexNoder.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -99,8 +99,8 @@
 			si(newSi)
 		{}
 
-		void overlap(index::chain::MonotoneChain& mc1, size_t start1,
-            index::chain::MonotoneChain& mc2, size_t start2);
+		void overlap(index::chain::MonotoneChain& mc1, std::size_t start1,
+            index::chain::MonotoneChain& mc2, std::size_t start2);
     private:
         SegmentIntersector& si;
 

Modified: trunk/include/geos/noding/MCIndexSegmentSetMutualIntersector.h
===================================================================
--- trunk/include/geos/noding/MCIndexSegmentSetMutualIntersector.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/noding/MCIndexSegmentSetMutualIntersector.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -84,8 +84,8 @@
           index::chain::MonotoneChainOverlapAction(), si(si)
           {}
 
-          void overlap(index::chain::MonotoneChain& mc1, size_t start1,
-              index::chain::MonotoneChain& mc2, size_t start2);
+          void overlap(index::chain::MonotoneChain& mc1, std::size_t start1,
+              index::chain::MonotoneChain& mc2, std::size_t start2);
     };
 
 private:

Modified: trunk/include/geos/noding/SegmentNodeList.h
===================================================================
--- trunk/include/geos/noding/SegmentNodeList.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/noding/SegmentNodeList.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -93,7 +93,7 @@
 	 * which are pre-existing in the vertex list.
 	 */
 	void findCollapsesFromExistingVertices(
-			std::vector<size_t>& collapsedVertexIndexes);
+			std::vector<std::size_t>& collapsedVertexIndexes);
 
 	/**
 	 * Adds nodes for any collapsed edge pairs caused by inserted nodes
@@ -103,7 +103,7 @@
 	 * the vertex must be added as a node as well.
 	 */
 	void findCollapsesFromInsertedNodes(
-		std::vector<size_t>& collapsedVertexIndexes);
+		std::vector<std::size_t>& collapsedVertexIndexes);
 
 	bool findCollapseIndex(SegmentNode& ei0, SegmentNode& ei1,
 		size_t& collapsedVertexIndex);
@@ -140,9 +140,9 @@
 	 * @param intPt the intersection Coordinate, will be copied
 	 * @param segmentIndex 
 	 */
-	SegmentNode* add(const geom::Coordinate& intPt, size_t segmentIndex);
+	SegmentNode* add(const geom::Coordinate& intPt, std::size_t segmentIndex);
 
-	SegmentNode* add(const geom::Coordinate *intPt, size_t segmentIndex) {
+	SegmentNode* add(const geom::Coordinate *intPt, std::size_t segmentIndex) {
 		return add(*intPt, segmentIndex);
 	}
 

Modified: trunk/include/geos/noding/SegmentStringUtil.h
===================================================================
--- trunk/include/geos/noding/SegmentStringUtil.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/noding/SegmentStringUtil.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -62,7 +62,7 @@
 		geom::LineString::ConstVect lines;
 		geom::util::LinearComponentExtracter::getLines(*g, lines);
 
-		for (size_t i=0, n=lines.size(); i<n; i++)
+		for (std::size_t i=0, n=lines.size(); i<n; i++)
 		{
 			geom::LineString* line = (geom::LineString*)(lines[i]);
 

Modified: trunk/include/geos/noding/snapround/HotPixel.h
===================================================================
--- trunk/include/geos/noding/snapround/HotPixel.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/noding/snapround/HotPixel.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -171,7 +171,7 @@
 	 * @param segIndex
 	 * @return true if a node was added to the segment
 	 */
-	bool addSnappedNode(NodedSegmentString& segStr, size_t segIndex);
+	bool addSnappedNode(NodedSegmentString& segStr, std::size_t segIndex);
 
 };
 

Modified: trunk/include/geos/operation/predicate/RectangleIntersects.h
===================================================================
--- trunk/include/geos/operation/predicate/RectangleIntersects.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/operation/predicate/RectangleIntersects.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -66,7 +66,7 @@
 	 * Must be determined empirically.  Should err on the
 	 * safe side by making value smaller rather than larger.
 	 */
-	static const size_t MAXIMUM_SCAN_SEGMENT_COUNT;
+	static const std::size_t MAXIMUM_SCAN_SEGMENT_COUNT;
 
 	/** \brief
 	 * Create a new intersects computer for a rectangle.

Modified: trunk/include/geos/planargraph/DirectedEdgeStar.h
===================================================================
--- trunk/include/geos/planargraph/DirectedEdgeStar.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/planargraph/DirectedEdgeStar.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -86,7 +86,7 @@
 	 * \brief Returns the number of edges around the Node associated
 	 * with this DirectedEdgeStar.
 	 */
-	size_t getDegree() const { return outEdges.size(); }
+	 std::size_t getDegree() const { return outEdges.size(); }
 
 	/**
 	 * \brief Returns the coordinate for the node at wich this

Modified: trunk/include/geos/planargraph/PlanarGraph.h
===================================================================
--- trunk/include/geos/planargraph/PlanarGraph.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/planargraph/PlanarGraph.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -230,7 +230,7 @@
 	 * Returns all Nodes with the given number of Edges around it.
  	 * The return value is a newly allocated vector of existing nodes
 	 */
-	std::vector<Node*>* findNodesOfDegree(size_t degree);
+	std::vector<Node*>* findNodesOfDegree(std::size_t degree);
 };
 
 } // namespace geos::planargraph

Modified: trunk/include/geos/simplify/DouglasPeuckerLineSimplifier.h
===================================================================
--- trunk/include/geos/simplify/DouglasPeuckerLineSimplifier.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/simplify/DouglasPeuckerLineSimplifier.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -81,7 +81,7 @@
 	BoolVectAutoPtr usePt;
 	double distanceTolerance;
 
-	void simplifySection(size_t i, size_t j);
+	void simplifySection(std::size_t i, std::size_t j);
 
     // Declare type as noncopyable
     DouglasPeuckerLineSimplifier(const DouglasPeuckerLineSimplifier& other);

Modified: trunk/include/geos/simplify/TaggedLineString.h
===================================================================
--- trunk/include/geos/simplify/TaggedLineString.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/simplify/TaggedLineString.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -80,9 +80,9 @@
 
 	size_t getResultSize() const;
 
-	TaggedLineSegment* getSegment(size_t);
+	TaggedLineSegment* getSegment(std::size_t);
 
-	const TaggedLineSegment* getSegment(size_t) const;
+	const TaggedLineSegment* getSegment(std::size_t) const;
 
 	std::vector<TaggedLineSegment*>& getSegments();
 



More information about the geos-commits mailing list
--- trunk/include/geos/geom/CoordinateSequence.h	2010-03-29 12:13:37 UTC (rev 2960)
+++ trunk/include/geos/geom/CoordinateSequence.h	2010-03-29 12:17:37 UTC (rev 2961)
@@ -95,7 +95,7 @@
 	 * Coordinate or merely a copy depends on the implementation.
 	 */
 	//virtual const Coordinate& getCoordinate(int i) const=0;
-	virtual const Coordinate& getAt(size_t i) const=0;
+	virtual const Coordinate& getAt(std::size_t i) const=0;
 
 	/// Return last Coordinate in the sequence
 	const Coordinate& back() const {
@@ -107,21 +107,21 @@
 		return getAt(0);
 	}
 
-	const Coordinate& operator[] (size_t i) const {
+	const Coordinate& operator[] (std::size_t i) const {
 		return getAt(i);
 	}
 
 	/** \brief
 	 * Write Coordinate at position i to given Coordinate.
 	 */
-	virtual void getAt(size_t i, Coordinate& c) const=0;
+	virtual void getAt(std::size_t i, Coordinate& c) const=0;
 
 	/** \brief
 	 * Returns the number of Coordinates (actual or otherwise, as
 	 * this implementation may not store its data in Coordinate objects).
 	 */
 	//virtual int size() const=0;
-	virtual size_t getSize() const=0;
+	virtual std::size_t getSize() const=0;
 
 	size_t size() const { return getSize(); }
 
@@ -200,7 +200,7 @@
 	 *
 	 * NOTE: this is a CoordinateList interface in JTS
 	 */
-	virtual void add(size_t i, const Coordinate& coord, bool allowRepeated)=0;
+	virtual void add(std::size_t i, const Coordinate& coord, bool allowRepeated)=0;
 
 	/// Returns <code>true</code> it list contains no coordinates.
 	virtual	bool isEmpty() const=0;
@@ -212,13 +212,13 @@
 	//virtual int getSize() const=0;
 
 	/// Get a reference to Coordinate at position pos
-	//virtual	const Coordinate& getAt(size_t pos) const=0;
+	//virtual	const Coordinate& getAt(std::size_t pos) const=0;
 
 	/// Copy Coordinate c to position pos
-	virtual	void setAt(const Coordinate& c, size_t pos)=0;
+	virtual	void setAt(const Coordinate& c, std::size_t pos)=0;
 
 	/// Delete Coordinate at position pos (list will shrink).
-	virtual	void deleteAt(size_t pos)=0;
+	virtual	void deleteAt(std::size_t pos)=0;
 
 	/// Get a string rapresentation of CoordinateSequence
 	virtual	std::string toString() const=0;
@@ -260,7 +260,7 @@
 	 *  Returns either the given CoordinateSequence if its length
 	 *  is greater than the given amount, or an empty CoordinateSequence.
 	 */
-	static CoordinateSequence* atLeastNCoordinatesOrNothing(size_t n,
+	static CoordinateSequence* atLeastNCoordinatesOrNothing(std::size_t n,
 			CoordinateSequence *c);
 
 	/** \brief
@@ -272,7 +272,7 @@
 
 	/// Return position of a Coordinate, or -1 if not found
 	//
 	/// FIXME: return size_t, using numeric_limits<size_t>::max
 	/// as 'not found' value.
 	///
 	static int indexOf(const Coordinate *coordinate,
@@ -320,7 +320,7 @@
 	 *
 	 * @return the dimension of the sequence.
 	 */
-	virtual size_t getDimension() const=0;
+	virtual std::size_t getDimension() const=0;
 
 	/**
 	 * Returns the ordinate of a coordinate in this sequence.
@@ -332,7 +332,7 @@
 	 * @param ordinateIndex the ordinate index in the coordinate
 	 * 	   (in range [0, dimension-1])
 	 */
-	virtual double getOrdinate(size_t index, size_t ordinateIndex) const=0;
+	virtual double getOrdinate(std::size_t index, std::size_t ordinateIndex) const=0;
 
 	/**
 	 * Returns ordinate X (0) of the specified coordinate.
@@ -340,7 +340,7 @@
 	 * @param index
 	 * @return the value of the X ordinate in the index'th coordinate
 	 */
-	virtual double getX(size_t index) const { return getOrdinate(index, X); }
+	virtual double getX(std::size_t index) const { return getOrdinate(index, X); }
 
 	/**
 	 * Returns ordinate Y (1) of the specified coordinate.
@@ -348,7 +348,7 @@
 	 * @param index
 	 * @return the value of the Y ordinate in the index'th coordinate
 	 */
-	virtual double getY(size_t index) const { return getOrdinate(index, Y); }
+	virtual double getY(std::size_t index) const { return getOrdinate(index, Y); }
 
 
 	/**
@@ -359,7 +359,7 @@
 	 * 		(in range [0, dimension-1])
 	 * @param value  the new ordinate value
 	 */
-	virtual void setOrdinate(size_t index, size_t ordinateIndex, double value)=0;
+	virtual void setOrdinate(std::size_t index, std::size_t ordinateIndex, double value)=0;
 
 	/**
 	 * Expands the given Envelope to include the coordinates in the
@@ -385,7 +385,7 @@
 	void applyCoordinateFilter(T& f) 
 	{
 		Coordinate c;
-		for(size_t i=0, n=size(); i<n; ++i)
+		for(std::size_t i=0, n=size(); i<n; ++i)
 		{
 			getAt(i, c);
 			f.filter(c);
@@ -272,7 +272,7 @@
 	/// Return position of a Coordinate, or -1 if not found
 	//
-	/// FIXME: return size_t, using numeric_limits<size_t>::max
+	/// FIXME: return std::size_t, using numeric_limits<std::size_t>::max
 	/// as 'not found' value.
 	///

Modified: trunk/include/geos/geom/CoordinateSequenceFactory.h
===================================================================